@@ -32,10 +32,10 @@ def get_coastline(ds, lon_name, lat_name):
     lat_max = ds[lat_name].values.max()
     lat_min = ds[lat_name].values.min()
 
-    if ((lon_max - lon_min) * (lat_max - lat_min)) / (360 ** 2) < 0.0016:
+    if ((lon_max - lon_min) * (lat_max - lat_min)) / (360**2) < 0.0016:
         return "10m"
 
-    if ((lon_max - lon_min) * (lat_max - lat_min)) / (360 ** 2) < 0.25:
+    if ((lon_max - lon_min) * (lat_max - lat_min)) / (360**2) < 0.25:
         return "50m"
 
     return "110m"
@@ -52,8 +52,21 @@ def change_coords(dx):
     lon_name = df_dims.longitude[0]
     lat_name = df_dims.latitude[0]
 
-    # if there are repeated zeros
-    if len([x for x in ds[lat_name].values[0] if x == 0]) <= 1:
+    lat_df = (
+        pd.DataFrame(ds[lat_name].values)
+        .melt()
+        .groupby("value")
+        .size()
+        .sort_values(ascending=False)
+        .reset_index()
+    )
+    lat_df.columns = ["value", "number"]
+
+    if lat_df.number[0] / lat_df.number[1] < 10:
+        #    switch_coords = True
+
+        ## if there are repeated zeros
+        # if len([x for x in ds[lat_name].values[0] if x == 0]) <= 1:
         return ds
 
     if sum(ds[lon_name].values[0] == ds[lon_name].values[1]) == len(ds[lon_name][0]):
@@ -84,6 +97,11 @@ def change_coords(dx):
     else:
         ds = ds.rename({lat_name: "y"})
 
+    if "x_coord" in ds.coords:
+        ds["x_coord"] = ds["x"]
+        ds["y_coord"] = ds["y"]
+        ds = ds.rename({"x_coord": "x"}).rename({"y_coord": "y"})
+
     return ds
 
 
@@ -122,7 +140,7 @@ def in_notebook():
     return "ipykernel" in sys.modules
 
 
-def view(x, vars=None):
+def view(x, vars=None, autoscale=True):
     """
     Plot the contents of a NetCDF file
     Parameters
@@ -152,6 +170,9 @@ def view(x, vars=None):
     else:
         ds = x
 
+    if type(vars) is list:
+        ds = ds[vars]
+
     coord_list = list(ds.coords)
 
     for cc in coord_list:
@@ -226,7 +247,7 @@ def view(x, vars=None):
         orig_coords = list(ds.coords)
         ds = change_coords(ds)
         new_coords = list(ds.coords)
-        quadmesh = True
+        quadmesh = False
         df_dims = get_dims(ds)
         # figure out number of points
         lon_name = df_dims.longitude[0]
@@ -273,6 +294,9 @@ def view(x, vars=None):
         if len(ds[lat_name].values) > 1:
             n_points += len(ds[lat_name].values)
 
+    if "lon" not in lon_name:
+        coastline = False
+
     ff_dims = list(ds.coords)
 
     possible_others = [x for x in ff_dims if x not in df_dims.columns]
@@ -352,10 +376,17 @@ def view(x, vars=None):
 
     coord_list = list(ds.coords)
 
+    coord_list = [x for x in coord_list if x in list(ds.dims)]
+
     coord_df = pd.DataFrame(
         {"coord": coord_list, "length": [len(ds.coords[x].values) for x in coord_list]}
     )
 
+    # It's possible there are still 2 time variables in the dimensions which could cause problems...
+
+    for tt in [x for x in ds.coords if "time" in x and x != time_name]:
+        ds = ds.drop_vars(tt)
+
     # work out if it should be a spatial map
 
     spatial_map = False
@@ -452,9 +483,14 @@ def view(x, vars=None):
 
             else:
 
-                self_max = ds.rename({vars: "x"}).x.max()
-                self_min = ds.rename({vars: "x"}).x.min()
-                v_max = float(max(self_max.values, -self_min.values))
+                if autoscale:
+
+                    self_max = ds.rename({vars: "x"}).x.max()
+                    self_min = ds.rename({vars: "x"}).x.min()
+                    v_max = float(max(self_max.values, -self_min.values))
+                else:
+                    self_max = 1
+                    self_min = 1
 
                 # figure out if it needs to be quadmesh
                 if x_var == time_name:
@@ -723,11 +759,15 @@ def view(x, vars=None):
             warnings.warn(message="Warning: Only the first variable is mapped")
             vars = vars[0]
 
-        self_max = ds.rename({vars: "x_dim12345"}).x_dim12345.max()
-        self_min = ds.rename({vars: "x_dim12345"}).x_dim12345.min()
-        v_max = max(self_max.values, -self_min.values)
+        if autoscale:
+            self_max = ds.rename({vars: "x_dim12345"}).x_dim12345.max()
+            self_min = ds.rename({vars: "x_dim12345"}).x_dim12345.min()
+            v_max = max(self_max.values, -self_min.values)
+        else:
+            self_max = 1
+            self_min = 1
 
-        if (self_max.values > 0) and (self_min.values < 0):
+        if (self_max > 0) and (self_min < 0):
             if quadmesh:
                 if coastline:
                     coastline = get_coastline(ds, lon_name, lat_name)
@@ -735,17 +775,30 @@ def view(x, vars=None):
                 else:
                     projection = None
 
-                intplot = ds.hvplot.quadmesh(
-                    lon_name,
-                    lat_name,
-                    vars,
-                    dynamic=True,
-                    cmap="RdBu_r",
-                    coastline=coastline,
-                    projection=projection,
-                    rasterize=rasterize,
-                    responsive=(in_notebook() is False),
-                ).redim.range(**{vars: (-v_max, v_max)})
+                if autoscale:
+                    intplot = ds.hvplot.quadmesh(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        cmap="RdBu_r",
+                        coastline=coastline,
+                        projection=projection,
+                        rasterize=rasterize,
+                        responsive=(in_notebook() is False),
+                    ).redim.range(**{vars: (-v_max, v_max)})
+                else:
+                    intplot = ds.hvplot.quadmesh(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        cmap="RdBu_r",
+                        coastline=coastline,
+                        projection=projection,
+                        rasterize=rasterize,
+                        responsive=(in_notebook() is False),
+                    )
                 # intplot = pn.Row(pn.WidgetBox(w1), intplot)
             else:
                 if coastline:
@@ -754,17 +807,30 @@ def view(x, vars=None):
                 else:
                     projection = None
 
-                intplot = ds.hvplot.image(
-                    lon_name,
-                    lat_name,
-                    vars,
-                    dynamic=True,
-                    coastline=coastline,
-                    projection=projection,
-                    rasterize=False,
-                    cmap="RdBu_r",
-                    responsive=(in_notebook() is False),
-                ).redim.range(**{vars: (-v_max, v_max)})
+                if autoscale:
+                    intplot = ds.hvplot.image(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        coastline=coastline,
+                        projection=projection,
+                        rasterize=False,
+                        cmap="RdBu_r",
+                        responsive=(in_notebook() is False),
+                    ).redim.range(**{vars: (-v_max, v_max)})
+                else:
+                    intplot = ds.hvplot.image(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        coastline=coastline,
+                        projection=projection,
+                        rasterize=False,
+                        cmap="RdBu_r",
+                        responsive=(in_notebook() is False),
+                    )
 
             if in_notebook():
                 return intplot
@@ -783,17 +849,31 @@ def view(x, vars=None):
                     projection = ccrs.PlateCarree()
                 else:
                     projection = None
-                intplot = ds.hvplot.quadmesh(
-                    lon_name,
-                    lat_name,
-                    vars,
-                    dynamic=True,
-                    cmap="viridis",
-                    coastline=coastline,
-                    projection=projection,
-                    rasterize=rasterize,
-                    responsive=(in_notebook() is False),
-                ).redim.range(**{vars: (self_min.values, v_max)})
+                if autoscale:
+                    intplot = ds.hvplot.quadmesh(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        cmap="viridis",
+                        coastline=coastline,
+                        projection=projection,
+                        rasterize=rasterize,
+                        responsive=(in_notebook() is False),
+                    ).redim.range(**{vars: (self_min.values, v_max)})
+                else:
+                    intplot = ds.hvplot.quadmesh(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        cmap="viridis",
+                        coastline=coastline,
+                        projection=projection,
+                        rasterize=rasterize,
+                        responsive=(in_notebook() is False),
+                    )
+
             else:
 
                 if coastline:
@@ -802,17 +882,30 @@ def view(x, vars=None):
                 else:
                     projection = None
 
-                intplot = ds.hvplot.image(
-                    lon_name,
-                    lat_name,
-                    vars,
-                    dynamic=True,
-                    cmap="viridis",
-                    coastline=coastline,
-                    rasterize=False,
-                    projection=projection,
-                    responsive=(in_notebook() is False),
-                ).redim.range(**{vars: (self_min.values, v_max)})
+                if autoscale:
+                    intplot = ds.hvplot.image(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        cmap="viridis",
+                        coastline=coastline,
+                        rasterize=False,
+                        projection=projection,
+                        responsive=(in_notebook() is False),
+                    ).redim.range(**{vars: (self_min.values, v_max)})
+                else:
+                    intplot = ds.hvplot.image(
+                        lon_name,
+                        lat_name,
+                        vars,
+                        dynamic=True,
+                        cmap="viridis",
+                        coastline=coastline,
+                        rasterize=False,
+                        projection=projection,
+                        responsive=(in_notebook() is False),
+                    )
 
             if in_notebook():
                 return intplot
