@@ -79,19 +79,19 @@ def get_dims(ff):
                 for x in ds[var].metpy.coordinates("longitude"):
                     lon_name = x.name
             except:
-                lon_name = lon_name
+                lon_name = None
 
             try:
                 for x in ds[var].metpy.coordinates("latitude"):
                     lat_name = x.name
             except:
-                lat_name = lat_name
+                lat_name = None
 
             try:
                 for x in ds[var].metpy.coordinates("time"):
                     time_name = x.name
             except:
-                time_name = lat_name
+                time_name = None
 
         # it's possible metpy will not parse lat/lon properly. In this case check if "lon"/"lat" appear in dims once
         if lon_name is None or lat_name is None:
@@ -146,6 +146,9 @@ def get_dims(ff):
 
         times = [x for x in ff_dims if r"time" in x]
         if len(times) > 1:
+            times = [x for x in list(ds.dims)  if x in list(ds.coords) if "time" in x]
+
+        if len(times) != 1:
             raise ValueError("Cannot parse dimension names!")
 
         if len(times) == 0:
